==> jc-1.4.0.tar.gz: soot/jimple/internal/JAssignStmt__241.h <==
// class soot.jimple.internal.JAssignStmt$1

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 284aff14bea3930f soot_jimple_AbstractJimpleValueSwitch
// @dep_class 13e1527f81a59ba3 soot_jimple_internal_JAssignStmt__241

// header file dependencies
// @dep_header soot_jimple_AbstractJimpleValueSwitch

#include "soot/jimple/AbstractJimpleValueSwitch.h"

#ifndef _JC_soot_jimple_internal_JAssignStmt__241_H_
#define _JC_soot_jimple_internal_JAssignStmt__241_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_soot_Local$object;
struct _jc_soot_Value$object;
struct _jc_soot_jimple_ArrayRef$object;
struct _jc_soot_jimple_InstanceFieldRef$object;
struct _jc_soot_jimple_JimpleToBafContext$object;
struct _jc_soot_jimple_StaticFieldRef$object;
struct _jc_soot_jimple_internal_JAssignStmt$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_JAssignStmt__241$sub_refs	_jc_soot_jimple_internal_JAssignStmt__241$sub_refs;
typedef struct _jc_soot_jimple_internal_JAssignStmt__241$sub_nonrefs	_jc_soot_jimple_internal_JAssignStmt__241$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_JAssignStmt__241$refs	_jc_soot_jimple_internal_JAssignStmt__241$refs;
typedef struct _jc_soot_jimple_internal_JAssignStmt__241$nonrefs	_jc_soot_jimple_internal_JAssignStmt__241$nonrefs;
typedef struct _jc_soot_jimple_internal_JAssignStmt__241$object	_jc_soot_jimple_internal_JAssignStmt__241$object;

typedef const struct _jc_soot_jimple_internal_JAssignStmt__241$vmethods	_jc_soot_jimple_internal_JAssignStmt__241$vmethods;
typedef const struct _jc_soot_jimple_internal_JAssignStmt__241$vtable	_jc_soot_jimple_internal_JAssignStmt__241$vtable;
typedef const struct _jc_soot_jimple_internal_JAssignStmt__241$vtype	_jc_soot_jimple_internal_JAssignStmt__241$vtype;

// Constructors
extern void _jc_soot_jimple_internal_JAssignStmt__241$method$_init$bdd3eac8ac96b38d(_jc_env *, struct _jc_soot_jimple_internal_JAssignStmt__241$object *, struct _jc_soot_jimple_internal_JAssignStmt$object *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern void _jc_soot_jimple_internal_JAssignStmt__241$method$caseArrayRef$21785baef489451a(_jc_env *, struct _jc_soot_jimple_internal_JAssignStmt__241$object *, struct _jc_object *);
extern void _jc_soot_jimple_internal_JAssignStmt__241$method$caseInstanceFieldRef$edd1ca12bae45903(_jc_env *, struct _jc_soot_jimple_internal_JAssignStmt__241$object *, struct _jc_object *);
extern void _jc_soot_jimple_internal_JAssignStmt__241$method$caseLocal$22d2ce69207555ad(_jc_env *, struct _jc_soot_jimple_internal_JAssignStmt__241$object *, struct _jc_object *);
extern void _jc_soot_jimple_internal_JAssignStmt__241$method$caseStaticFieldRef$80e41c7d355e896d(_jc_env *, struct _jc_soot_jimple_internal_JAssignStmt__241$object *, struct _jc_soot_jimple_StaticFieldRef$object *);
extern void _jc_soot_jimple_internal_JAssignStmt__241$method$defaultCase$707752a9a764fffd(_jc_env *, struct _jc_soot_jimple_internal_JAssignStmt__241$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_JAssignStmt__241$method_info$caseArrayRef$21785baef489451a;
extern _jc_method _jc_soot_jimple_internal_JAssignStmt__241$method_info$caseInstanceFieldRef$edd1ca12bae45903;
extern _jc_method _jc_soot_jimple_internal_JAssignStmt__241$method_info$caseLocal$22d2ce69207555ad;
extern _jc_method _jc_soot_jimple_internal_JAssignStmt__241$method_info$caseStaticFieldRef$80e41c7d355e896d;
extern _jc_method _jc_soot_jimple_internal_JAssignStmt__241$method_info$defaultCase$707752a9a764fffd;

// Virtual methods structure
struct _jc_soot_jimple_internal_JAssignStmt__241$vmethods {
	void	(*caseArrayRef$21785baef489451a)(_jc_env *, struct _jc_soot_jimple_internal_JAssignStmt__241$object *, struct _jc_object *);
	void	(*caseInstanceFieldRef$edd1ca12bae45903)(_jc_env *, struct _jc_soot_jimple_internal_JAssignStmt__241$object *, struct _jc_object *);
	void	(*caseLocal$22d2ce69207555ad)(_jc_env *, struct _jc_soot_jimple_internal_JAssignStmt__241$object *, struct _jc_object *);
	void	(*caseStaticFieldRef$80e41c7d355e896d)(_jc_env *, struct _jc_soot_jimple_internal_JAssignStmt__241$object *, struct _jc_soot_jimple_StaticFieldRef$object *);
	void	(*defaultCase$707752a9a764fffd)(_jc_env *, struct _jc_soot_jimple_internal_JAssignStmt__241$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_jimple_internal_JAssignStmt__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_AbstractJimpleValueSwitch$vmethods	soot_jimple_AbstractJimpleValueSwitch;
	_jc_soot_jimple_internal_JAssignStmt__241$vmethods	soot_jimple_internal_JAssignStmt__241;
};

// Vtype
struct _jc_soot_jimple_internal_JAssignStmt__241$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_JAssignStmt__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_JAssignStmt__241$sub_refs {
	struct _jc_soot_jimple_JimpleToBafContext$object	*val__24context;
	struct _jc_object	*val__24out;
	struct _jc_object	*val__24rvalue;
	struct _jc_soot_jimple_internal_JAssignStmt$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_JAssignStmt__241$refs {
    _jc_soot_jimple_internal_JAssignStmt__241$sub_refs	soot_jimple_internal_JAssignStmt__241;
    _jc_soot_jimple_AbstractJimpleValueSwitch$sub_refs	soot_jimple_AbstractJimpleValueSwitch;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_JAssignStmt__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_JAssignStmt__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_AbstractJimpleValueSwitch$sub_nonrefs	soot_jimple_AbstractJimpleValueSwitch;
    _jc_soot_jimple_internal_JAssignStmt__241$sub_nonrefs	soot_jimple_internal_JAssignStmt__241;
};

// Object instance structure
struct _jc_soot_jimple_internal_JAssignStmt__241$object {
	_jc_soot_jimple_internal_JAssignStmt__241$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_JAssignStmt__241$vtype	*vtype;
	_jc_soot_jimple_internal_JAssignStmt__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_JAssignStmt__241$vtype _jc_soot_jimple_internal_JAssignStmt__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_JAssignStmt__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_JAssignStmt__241$class_object;

#endif	/* _JC_soot_jimple_internal_JAssignStmt__241_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/internal/JAssignStmt__241.h <==
// class soot.jimple.internal.JAssignStmt$1

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 284aff14bea3930f soot_jimple_AbstractJimpleValueSwitch
// @dep_class 13e1527f81a59ba3 soot_jimple_internal_JAssignStmt__241

// header file dependencies
// @dep_header soot_jimple_AbstractJimpleValueSwitch

#include "soot/jimple/AbstractJimpleValueSwitch.h"

#ifndef _JC_soot_jimple_internal_JAssignStmt__241_H_
#define _JC_soot_jimple_internal_JAssignStmt__241_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_soot_Local$object;
struct _jc_soot_Value$object;
struct _jc_soot_jimple_ArrayRef$object;
struct _jc_soot_jimple_InstanceFieldRef$object;
struct _jc_soot_jimple_JimpleToBafContext$object;
struct _jc_soot_jimple_StaticFieldRef$object;
struct _jc_soot_jimple_internal_JAssignStmt$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_JAssignStmt__241$sub_refs	_jc_soot_jimple_internal_JAssignStmt__241$sub_refs;
typedef struct _jc_soot_jimple_internal_JAssignStmt__241$sub_nonrefs	_jc_soot_jimple_internal_JAssignStmt__241$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_JAssignStmt__241$refs	_jc_soot_jimple_internal_JAssignStmt__241$refs;
typedef struct _jc_soot_jimple_internal_JAssignStmt__241$nonrefs	_jc_soot_jimple_internal_JAssignStmt__241$nonrefs;
typedef struct _jc_soot_jimple_internal_JAssignStmt__241$object	_jc_soot_jimple_internal_JAssignStmt__241$object;

typedef const struct _jc_soot_jimple_internal_JAssignStmt__241$vmethods	_jc_soot_jimple_internal_JAssignStmt__241$vmethods;
typedef const struct _jc_soot_jimple_internal_JAssignStmt__241$vtable	_jc_soot_jimple_internal_JAssignStmt__241$vtable;
typedef const struct _jc_soot_jimple_internal_JAssignStmt__241$vtype	_jc_soot_jimple_internal_JAssignStmt__241$vtype;

// Constructors
extern void _jc_soot_jimple_internal_JAssignStmt__241$method$_init$bdd3eac8ac96b38d(_jc_env *, struct _jc_soot_jimple_internal_JAssignStmt__241$object *, struct _jc_soot_jimple_internal_JAssignStmt$object *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_internal_JAssignStmt__241$method$caseArrayRef$21785baef489451a(_jc_env *, struct _jc_soot_jimple_internal_JAssignStmt__241$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_internal_JAssignStmt__241$method$caseInstanceFieldRef$edd1ca12bae45903(_jc_env *, struct _jc_soot_jimple_internal_JAssignStmt__241$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_internal_JAssignStmt__241$method$caseLocal$22d2ce69207555ad(_jc_env *, struct _jc_soot_jimple_internal_JAssignStmt__241$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_internal_JAssignStmt__241$method$caseStaticFieldRef$80e41c7d355e896d(_jc_env *, struct _jc_soot_jimple_internal_JAssignStmt__241$object *, struct _jc_soot_jimple_StaticFieldRef$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_internal_JAssignStmt__241$method$defaultCase$707752a9a764fffd(_jc_env *, struct _jc_soot_jimple_internal_JAssignStmt__241$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_JAssignStmt__241$method_info$caseArrayRef$21785baef489451a;
extern _jc_method _jc_soot_jimple_internal_JAssignStmt__241$method_info$caseInstanceFieldRef$edd1ca12bae45903;
extern _jc_method _jc_soot_jimple_internal_JAssignStmt__241$method_info$caseLocal$22d2ce69207555ad;
extern _jc_method _jc_soot_jimple_internal_JAssignStmt__241$method_info$caseStaticFieldRef$80e41c7d355e896d;
extern _jc_method _jc_soot_jimple_internal_JAssignStmt__241$method_info$defaultCase$707752a9a764fffd;

// Virtual methods structure
struct _jc_soot_jimple_internal_JAssignStmt__241$vmethods {
	void	(*caseArrayRef$21785baef489451a)(_jc_env *, struct _jc_soot_jimple_internal_JAssignStmt__241$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*caseInstanceFieldRef$edd1ca12bae45903)(_jc_env *, struct _jc_soot_jimple_internal_JAssignStmt__241$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*caseLocal$22d2ce69207555ad)(_jc_env *, struct _jc_soot_jimple_internal_JAssignStmt__241$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*caseStaticFieldRef$80e41c7d355e896d)(_jc_env *, struct _jc_soot_jimple_internal_JAssignStmt__241$object *, struct _jc_soot_jimple_StaticFieldRef$object *) _JC_JCNI_ATTR;
	void	(*defaultCase$707752a9a764fffd)(_jc_env *, struct _jc_soot_jimple_internal_JAssignStmt__241$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_internal_JAssignStmt__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_AbstractJimpleValueSwitch$vmethods	soot_jimple_AbstractJimpleValueSwitch;
	_jc_soot_jimple_internal_JAssignStmt__241$vmethods	soot_jimple_internal_JAssignStmt__241;
};

// Vtype
struct _jc_soot_jimple_internal_JAssignStmt__241$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_JAssignStmt__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_JAssignStmt__241$sub_refs {
	struct _jc_soot_jimple_JimpleToBafContext$object	*val__24context;
	struct _jc_object	*val__24out;
	struct _jc_object	*val__24rvalue;
	struct _jc_soot_jimple_internal_JAssignStmt$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_JAssignStmt__241$refs {
    _jc_soot_jimple_internal_JAssignStmt__241$sub_refs	soot_jimple_internal_JAssignStmt__241;
    _jc_soot_jimple_AbstractJimpleValueSwitch$sub_refs	soot_jimple_AbstractJimpleValueSwitch;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_JAssignStmt__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_JAssignStmt__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_AbstractJimpleValueSwitch$sub_nonrefs	soot_jimple_AbstractJimpleValueSwitch;
    _jc_soot_jimple_internal_JAssignStmt__241$sub_nonrefs	soot_jimple_internal_JAssignStmt__241;
};

// Object instance structure
struct _jc_soot_jimple_internal_JAssignStmt__241$object {
	_jc_soot_jimple_internal_JAssignStmt__241$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_JAssignStmt__241$vtype	*vtype;
	_jc_soot_jimple_internal_JAssignStmt__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_JAssignStmt__241$vtype _jc_soot_jimple_internal_JAssignStmt__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_JAssignStmt__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_JAssignStmt__241$class_object;

#endif	/* _JC_soot_jimple_internal_JAssignStmt__241_H_ */
